# GetChargeOverride

Charge associated with a rate plan. 

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**billing** | [**ChargeOverrideBilling**](ChargeOverrideBilling.md) |  | [optional] 
**charge_number** | **str** | Charge number of the charge. For example, C-00000307.  If you do not set this field, Zuora will generate the charge number.  | [optional] 
**custom_fields** | **Dict[str, object]** | Container for custom fields of a Rate Plan Charge object.  | [optional] 
**description** | **str** | Description of the charge.  | [optional] 
**drawdown_rate** | **float** | **Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled.  The [conversion rate](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown/Create_drawdown_charge#UOM_Conversion) between Usage UOM and Drawdown UOM for a [drawdown charge](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown/Create_drawdown_charge). Must be a positive number (&gt;0).  | [optional] 
**end_date** | [**EndConditions**](EndConditions.md) |  | [optional] 
**exclude_item_billing_from_revenue_accounting** | **bool** | The flag to exclude rate plan charge related invoice items, invoice item adjustments, credit memo items, and debit memo items from revenue accounting.   **Note**: This field is only available if you have the [Zuora Billing - Revenue Integration](https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration) feature enabled.   | [optional] 
**exclude_item_booking_from_revenue_accounting** | **bool** | The flag to exclude rate plan charges from revenue accounting.   **Note**: This field is only available if you have the [Zuora Billing - Revenue Integration](https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration) feature enabled.   | [optional] 
**is_allocation_eligible** | **bool** | This field is used to identify if the charge segment is allocation eligible in revenue recognition.  **Note**: This feature is in the **Early Adopter** phase. If you want to use the feature, submit a request at &lt;a href&#x3D;\&quot;https://support.zuora.com/\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Zuora Global Support&lt;/a&gt;, and we will evaluate whether the feature is suitable for your use cases.  | [optional] 
**is_rollover** | **bool** | **Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled.  To use this field, you must set the &#x60;X-Zuora-WSDL-Version&#x60; request header to 114 or higher. Otherwise, an error occurs.  The value is either \&quot;True\&quot; or \&quot;False\&quot;. It determines whether the rollover fields are needed.  | [optional] 
**is_unbilled** | **bool** | This field is used to dictate how to perform the accounting during revenue recognition.  **Note**: This feature is in the **Early Adopter** phase. If you want to use the feature, submit a request at &lt;a href&#x3D;\&quot;https://support.zuora.com/\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Zuora Global Support&lt;/a&gt;, and we will evaluate whether the feature is suitable for your use cases.  | [optional] 
**prepaid_quantity** | **float** | **Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled.  The number of units included in a [prepayment charge](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown/Create_prepayment_charge). Must be a positive number (&gt;0).  | [optional] 
**proration_option** | **str** |  | [optional] 
**pricing** | [**ChargeOverridePricing**](ChargeOverridePricing.md) |  | [optional] 
**product_rate_plan_charge_number** | **str** | Number of a product rate-plan charge for this subscription.  | [optional] 
**product_rateplan_charge_id** | **str** | Internal identifier of the product rate plan charge that the charge is based on.  | 
**rev_rec_code** | **str** | Revenue Recognition Code  | [optional] 
**rev_rec_trigger_condition** | [**RevRecTriggerCondition**](RevRecTriggerCondition.md) |  | [optional] 
**revenue_recognition_rule_name** | **str** | Specifies the revenue recognition rule, such as &#x60;Recognize upon invoicing&#x60; or &#x60;Recognize daily over time&#x60;.  | [optional] 
**rollover_apply** | [**RolloverApply**](RolloverApply.md) |  | [optional] 
**rollover_periods** | **float** | **Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled.  To use this field, you must set the &#x60;X-Zuora-WSDL-Version&#x60; request header to 114 or higher. Otherwise, an error occurs.  This field defines the number of rollover periods, it is restricted to 3.  | [optional] 
**start_date** | [**TriggerParams**](TriggerParams.md) |  | [optional] 
**unique_token** | **str** | Unique identifier for the charge. This identifier enables you to refer to the charge before the charge has an internal identifier in Zuora.  For instance, suppose that you want to use a single order to add a product to a subscription and later update the same product. When you add the product, you can set a unique identifier for the charge. Then when you update the product, you can use the same unique identifier to specify which charge to modify.  | [optional] 
**estimated_start_date** | **date** | **Note**: This field is only available if you have the [Pending Charge Flexibility] (https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Pending_Charge_Flexibility). feature enabled. Estimated Start Date of the charge. | [optional] 
**upsell_origin_charge_number** | **str** | **Note**: The Quantity Upsell feature is in Limited Availability. If you wish to have access to the feature, submit a request at [Zuora Global Support](https://support.zuora.com).  The identifier of the original upselling charge associated with the current charge.  | [optional] 
**taxable** | **bool** | **Note**: This field is only available only if you have Taxation enabled.  The flag to indicate whether the charge is taxable.  | [optional] 
**tax_mode** | [**TaxMode**](TaxMode.md) |  | [optional] 
**tax_code** | **str** | **Note**: This field is only available only if you have Taxation enabled.  The taxCode of a charge.  | [optional] 
**validity_period_type** | [**ValidityPeriodType**](ValidityPeriodType.md) |  | [optional] 
**product_category** | **str** | For standalone order, external product category. | [optional] 
**product_class** | **str** | For standalone order, external product class. | [optional] 
**product_family** | **str** | For standalone order, external product family. | [optional] 
**product_line** | **str** | For standalone order, external product line. | [optional] 

## Example

```python
from zuora_sdk.models.get_charge_override import GetChargeOverride

# TODO update the JSON string below
json = "{}"
# create an instance of GetChargeOverride from a JSON string
get_charge_override_instance = GetChargeOverride.from_json(json)
# print the JSON string representation of the object
print(GetChargeOverride.to_json())

# convert the object into a dict
get_charge_override_dict = get_charge_override_instance.to_dict()
# create an instance of GetChargeOverride from a dict
get_charge_override_from_dict = GetChargeOverride.from_dict(get_charge_override_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


